@@ -84,7 +84,7 @@ class CommunicationThread (threading.Thread):
                 elif image[0] == TEST_REPORT:    #[TEST_REPORT, email_1, email_2]
                     self.testReport(main_paras.sign_in_token, image[1], image[2])
                     continue
-            sendToApi(image, self.qForResult, self.passToken, ADDRESS)
+            sendToApi(image, self.qForResult, self.passToken, [main_paras.test_place, main_paras.test_city, main_paras.test_country])
             self.qForCom.task_done()
         
     def run(self):
