@@ -48,7 +48,7 @@ class WebApi(threading.Thread):
           "mode": main_paras.test_mode,
           "localdate": time.strftime("%d/%m/%Y",time.localtime(self.timeStamp)),
           "localtime": time.strftime("%H:%M:%S",time.localtime(self.timeStamp)),
-          "readerserial": SERIAL_NO
+          "readerserial": main_paras.serial
         })
         headers = {
           'Authorization': 'Basic bGFpcGFjOmxhaXBhY3dz',
