@@ -1,6 +1,6 @@
 try:
     from gpiozero import Button
-    from gpiozero import LED
+    from gpiozero import LED, PWMLED
     import time
 
     import sys, os, inspect
@@ -10,14 +10,15 @@ try:
 
     from define import *
 
-    fan=LED(FAN_PWM_PIN, initial_value=True)
+#    fan=LED(FAN_PWM_PIN, active_high=False, initial_value=True)
+    fan=PWMLED(FAN_PWM_PIN, active_high=False, initial_value=0, frequency = 100)
 
     def fanTurnOn(on):
         global fan
         if on:
-            fan.off()
+            fan.value=0.5
         else:
-            fan.on()
+            fan.value=0
     if __name__ == "__main__":
         fanTurnOn(True)
         time.sleep(5)
