@@ -8,6 +8,7 @@ parentdir = os.path.dirname(currentdir)
 sys.path.insert(0, parentdir)
 
 from define import *
+import main_paras
 powerButton = Button(POWER_BUTTON_PIN,True,None,None,POWER_BUTTON_HOLD_TIME)
 def shutDown():
     print("shut down now")
@@ -20,5 +21,14 @@ class OnOffThread (threading.Thread):
         self.name = name
 
     def run (self):
+        cmd = 'cat /proc/cpuinfo | grep Serial | cut -d \' \' -f 2'
+        main_paras.serial='LS2-'+subprocess.check_output([cmd], shell=True).decode("utf-8")
+        main_paras.serial = main_paras.serial.replace('\n','')
+        print(main_paras.serial)
+        
         powerButton.when_held=shutDown #takePhoto
             
+if __name__ == "__main__":
+    OnOff      =OnOffThread(4,"OnOff")
+
+    OnOff.start()
